@@ -1079,7 +1079,7 @@ class HPLCSample(HPLCSampleInfo):
             if self.directory is None:
                 raise ValueError('No directory was specified and the instance does not have a directory attribute.')
             directory = self.directory
-        directory = pathlib.Path(directory)
+        directory = pathlib.Path(directory).absolute()
         written_paths = []
         for signal in self.signals:
             file_name = directory / f'{signal}.csv'
@@ -1104,18 +1104,20 @@ class HPLCSample(HPLCSampleInfo):
                 f.write(f'{rt},{intensity},\n')
         return written_paths
 
-    def write_signals_to_xlsx(self, output_file: str = None) -> str:
+    def write_signals_to_xlsx(self, output_file: Union[str, pathlib.Path] = None) -> str:
         """
         Writes the signals to a single excel file.
 
-        :param output_file: target file. If this is not specified
+        :param output_file: target file path. If this is not specified
         :return: path to the written file
         """
         if output_file is None:
-            output_file = os.path.join(
-                os.path.dirname(self.spectrum.filename),
-                f'{self.spectrum.info["name"]}.xlsx'
-            )
+            output_file = pathlib.Path(self.spectrum.filename).parent / f'{self.spectrum.info["name"]}.xlsx'
+        elif isinstance(output_file, pathlib.Path) is False:
+            output_file = pathlib.Path(output_file)
+
+        if output_file.is_absolute() is False:
+            output_file = output_file.absolute()
 
         excel = openpyxl.Workbook()
 
